# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_sso_pb2 as admin_dot_v1_dot_integration__sso__pb2


class SsoServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetWorkOsOrg = channel.unary_unary(
                '/admin.v1.SsoService/GetWorkOsOrg',
                request_serializer=admin_dot_v1_dot_integration__sso__pb2.GetWorkOsOrgRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__sso__pb2.GetWorkOsOrgResponse.FromString,
                )
        self.UpdateWorkOsOrg = channel.unary_unary(
                '/admin.v1.SsoService/UpdateWorkOsOrg',
                request_serializer=admin_dot_v1_dot_integration__sso__pb2.UpdateWorkOsOrgRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__sso__pb2.UpdateWorkOsOrgResponse.FromString,
                )
        self.GetSsoConnections = channel.unary_unary(
                '/admin.v1.SsoService/GetSsoConnections',
                request_serializer=admin_dot_v1_dot_integration__sso__pb2.GetSsoConnectionsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__sso__pb2.GetSsoConnectionsResponse.FromString,
                )
        self.DeleteConnection = channel.unary_unary(
                '/admin.v1.SsoService/DeleteConnection',
                request_serializer=admin_dot_v1_dot_integration__sso__pb2.DeleteConnectionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__sso__pb2.DeleteConnectionResponse.FromString,
                )


class SsoServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetWorkOsOrg(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWorkOsOrg(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSsoConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SsoServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetWorkOsOrg': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkOsOrg,
                    request_deserializer=admin_dot_v1_dot_integration__sso__pb2.GetWorkOsOrgRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__sso__pb2.GetWorkOsOrgResponse.SerializeToString,
            ),
            'UpdateWorkOsOrg': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWorkOsOrg,
                    request_deserializer=admin_dot_v1_dot_integration__sso__pb2.UpdateWorkOsOrgRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__sso__pb2.UpdateWorkOsOrgResponse.SerializeToString,
            ),
            'GetSsoConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSsoConnections,
                    request_deserializer=admin_dot_v1_dot_integration__sso__pb2.GetSsoConnectionsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__sso__pb2.GetSsoConnectionsResponse.SerializeToString,
            ),
            'DeleteConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConnection,
                    request_deserializer=admin_dot_v1_dot_integration__sso__pb2.DeleteConnectionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__sso__pb2.DeleteConnectionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.SsoService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SsoService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetWorkOsOrg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SsoService/GetWorkOsOrg',
            admin_dot_v1_dot_integration__sso__pb2.GetWorkOsOrgRequest.SerializeToString,
            admin_dot_v1_dot_integration__sso__pb2.GetWorkOsOrgResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWorkOsOrg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SsoService/UpdateWorkOsOrg',
            admin_dot_v1_dot_integration__sso__pb2.UpdateWorkOsOrgRequest.SerializeToString,
            admin_dot_v1_dot_integration__sso__pb2.UpdateWorkOsOrgResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSsoConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SsoService/GetSsoConnections',
            admin_dot_v1_dot_integration__sso__pb2.GetSsoConnectionsRequest.SerializeToString,
            admin_dot_v1_dot_integration__sso__pb2.GetSsoConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SsoService/DeleteConnection',
            admin_dot_v1_dot_integration__sso__pb2.DeleteConnectionRequest.SerializeToString,
            admin_dot_v1_dot_integration__sso__pb2.DeleteConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_github_pb2 as admin_dot_v1_dot_integration__github__pb2


class GithubServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InstallGithubApp = channel.unary_unary(
                '/admin.v1.GithubService/InstallGithubApp',
                request_serializer=admin_dot_v1_dot_integration__github__pb2.InstallGithubAppRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__github__pb2.InstallGithubAppResponse.FromString,
                )
        self.GetGithubAppForOrg = channel.unary_unary(
                '/admin.v1.GithubService/GetGithubAppForOrg',
                request_serializer=admin_dot_v1_dot_integration__github__pb2.GetGithubAppForOrgRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__github__pb2.GetGithubAppForOrgResponse.FromString,
                )


class GithubServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def InstallGithubApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGithubAppForOrg(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GithubServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InstallGithubApp': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallGithubApp,
                    request_deserializer=admin_dot_v1_dot_integration__github__pb2.InstallGithubAppRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__github__pb2.InstallGithubAppResponse.SerializeToString,
            ),
            'GetGithubAppForOrg': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGithubAppForOrg,
                    request_deserializer=admin_dot_v1_dot_integration__github__pb2.GetGithubAppForOrgRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__github__pb2.GetGithubAppForOrgResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.GithubService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GithubService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def InstallGithubApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GithubService/InstallGithubApp',
            admin_dot_v1_dot_integration__github__pb2.InstallGithubAppRequest.SerializeToString,
            admin_dot_v1_dot_integration__github__pb2.InstallGithubAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGithubAppForOrg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.GithubService/GetGithubAppForOrg',
            admin_dot_v1_dot_integration__github__pb2.GetGithubAppForOrgRequest.SerializeToString,
            admin_dot_v1_dot_integration__github__pb2.GetGithubAppForOrgResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
